.. _lavue-filters:

LaVue Filters
=============

.. figure:: ../_images/lavuefilters.png

The **Filters** widget allows to change an image before displaying it by applying a set of user defined filters.

**Checkbox** switch on/off filters. They are applied in the order from left to right.


To configure filters see :ref:`filter-plugins-settings`

Examples of the filters can be found at :ref:`filter-plugins`
